define(['jquery'], function ($) {
	'use strict';
	 
	return function (SwatchRenderer) {
		$.widget('filoblu_omnibus.SwatchRenderer', $['mage']['SwatchRenderer'], {
			/**
			 * Render swatch options by part of config
			 *
			 * @param {Object} config
			 * @param {String} controlId
			 * @returns {String}
			 * @private
			 */
			_RenderSwatchOptions: function (config, controlId) {
				var optionConfig = this.options.jsonSwatchConfig[config.id],
					optionClass = this.options.classes.optionClass,
					moreLimit = parseInt(this.options.numberToShow, 10),
					moreClass = this.options.classes.moreButton,
					moreText = this.options.moreButtonText,
					countAttributes = 0,
					html = '';

				if (!this.options.jsonSwatchConfig.hasOwnProperty(config.id)) {
					return '';
				}

				$.each(config.options, function () {
					var id,
						type,
						value,
						thumb,
						label,
						attr,
						sku;

					if (!optionConfig.hasOwnProperty(this.id)) {
						return '';
					}

					// Add more button
					if (moreLimit === countAttributes++) {
						html += '<a href="#" class="' + moreClass + '">' + moreText + '</a>';
					}

					id = this.id;
					type = parseInt(optionConfig[id].type, 10);
					value = optionConfig[id].hasOwnProperty('value') ? optionConfig[id].value : '';
					thumb = optionConfig[id].hasOwnProperty('thumb') ? optionConfig[id].thumb : '';
					label = this.label ? this.label : '';
					sku = this.sku ? this.sku : '';
					attr =
						' id="' + controlId + '-item-' + id + '"' +
						' aria-checked="false"' +
						' aria-describedby="' + controlId + '"' +
						' tabindex="0"' +
						' option-type="' + type + '"' +
						' option-id="' + id + '"' +
						' option-label="' + label + '"' +
						' aria-label="' + label + '"' +
						' option-tooltip-thumb="' + thumb + '"' +
						' option-tooltip-value="' + value + '"' +
						' role="option"' +
						' option-sku="' + sku + '"';

					if (!this.hasOwnProperty('products') || this.products.length <= 0) {
						attr += ' option-empty="true"';
					}

					if (type === 0) {
						// Text
						html += '<div class="' + optionClass + ' text" ' + attr + '>' + (value ? value : label) +
							'</div>';
					} else if (type === 1) {
						// Color
						html += '<div class="' + optionClass + ' color" ' + attr +
							' style="background: ' + value +
							' no-repeat center; background-size: initial;">' + '' +
							'</div>';
					} else if (type === 2) {
						// Image
						html += '<div class="' + optionClass + ' image" ' + attr +
							' style="background: url(' + value + ') no-repeat center; background-size: initial;">' + '' +
							'</div>';
					} else if (type === 3) {
						// Clear
						html += '<div class="' + optionClass + '" ' + attr + '></div>';
					} else {
						// Default
						html += '<div class="' + optionClass + '" ' + attr + '>' + label + '</div>';
					}
				});

				return html;
			},
			/**
			 * Event for swatch options
			 *
			 * @param {Object} $this
			 * @param {Object} $widget
			 * @param {String|undefined} eventName
			 * @private
			 */
			_OnClick: function ($this, $widget, eventName) {
				var $parent = $this.parents('.' + $widget.options.classes.attributeClass),
					$wrapper = $this.parents('.' + $widget.options.classes.attributeOptionsWrapper),
					$label = $parent.find('.' + $widget.options.classes.attributeSelectedOptionLabelClass),
					attributeId = $parent.attr('attribute-id'),
					$input = $parent.find('.' + $widget.options.classes.attributeInput);
	
				if ($widget.inProductList) {
					$input = $widget.productForm.find(
						'.' + $widget.options.classes.attributeInput + '[name="super_attribute[' + attributeId + ']"]'
					);
				}
	
				if ($this.hasClass('disabled')) {
					return;
				}
	
				if ($this.hasClass('selected')) {
					$parent.removeAttr('option-selected').find('.selected').removeClass('selected');
					$input.val('');
					$label.text('');
					$this.attr('aria-checked', false);
				} else {
					$parent.attr('option-selected', $this.attr('option-id')).find('.selected').removeClass('selected');
					$label.text($this.attr('option-label'));
					$input.val($this.attr('option-id'));
					$input.attr('data-attr-name', this._getAttributeCodeById(attributeId));
					$this.addClass('selected');
					$widget._toggleCheckedAttributes($this, $wrapper);
				}
	
				$widget._Rebuild();
	
				if ($widget.element.parents($widget.options.selectorProduct)
						.find(this.options.selectorProductPrice).is(':data(mage-priceBox)')
				) {
					$widget._UpdatePrice();
				}
	
				$widget._loadMedia(eventName);
				$input.trigger('change');

				if (window.omnibusData?.enabled) {
					var sku = $this.attr("option-sku");

					if (sku) {
						var optionPricesKey;

						$widget.options.jsonConfig.attributes.forEach((attribute) => {
							optionPricesKey = attribute.options.find((option) => option.sku === sku)?.products[0];
						});

						if (
							optionPricesKey &&
							$widget.options.jsonConfig.optionPrices[optionPricesKey].finalPrice.amount <
								$widget.options.jsonConfig.optionPrices[optionPricesKey].oldPrice.amount &&
							window.omnibusData.apiUrl &&
							window.omnibusData.brand &&
							window.omnibusData.market
						) {
							$.ajax({
								url: window.omnibusData.apiUrl,
								data: {
									brand: window.omnibusData.brand,
									sku: sku,
									market: window.omnibusData.market,
								},
								complete: function () {
									if ($(".omnibus-price").hasClass("no-display")) {
										$(".omnibus-price").removeClass("no-display");
									}
								},
								error: function () {
									if ($(".price", ".omnibus-price").length) {
										$(".price", ".omnibus-price").text(
											priceUtils.formatPrice(
												$widget.options.jsonConfig.optionPrices[optionPricesKey].oldPrice
													.amount
											)
										);
									}
									
									console.log("An error occurred when calculating the omnibus price");
								},
								success: function (response) {
									if (response.price && $(".price", ".omnibus-price").length) {
										$(".price", ".omnibus-price").text(priceUtils.formatPrice(response.price));
									}
								},
							});
						}
					}
				}
			}
		});

		return $['filoblu_omnibus']['SwatchRenderer'];
	}
});